/*******************************************************************************
 * Copyright (c) 2014 BREDEX GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     BREDEX GmbH - initial API and implementation and/or initial documentation
 *******************************************************************************/
package org.eclipse.jubula.toolkit.concrete.internal.impl;

import org.eclipse.jdt.annotation.NonNull;
import org.eclipse.jdt.annotation.Nullable;
import org.eclipse.jubula.communication.CAP;
import org.eclipse.jubula.toolkit.CapBuilder;
import org.eclipse.jubula.toolkit.enums.ValueSets.*;
import javax.annotation.Generated;

import org.apache.commons.lang.Validate;
import org.apache.commons.lang.StringUtils;

import org.eclipse.jubula.communication.internal.message.MessageCap;
import org.eclipse.jubula.communication.internal.message.MessageParam;
import org.eclipse.jubula.tools.ComponentIdentifier;
import org.eclipse.jubula.tools.internal.constants.TestDataConstants;
import org.eclipse.jubula.tools.internal.objects.IComponentIdentifier;
import org.eclipse.jubula.toolkit.internal.annotations.RealizedType;
import org.eclipse.jubula.toolkit.internal.annotations.TesterClass;

/**
 * Class representing the TreeTableComponent component from the concrete toolkit.
 * @since 5.0
 */
@RealizedType(realizedType="guidancer.concrete.Tree")
@Generated(value = "org.eclipse.jubula.toolkit.api.gen.ComponentClassGenerator", 
           date =  "2020-02-26T08:09:53.769Z")
public class TreeTableComponent extends org.eclipse.jubula.toolkit.concrete.internal.impl.TreeComponent implements org.eclipse.jubula.toolkit.concrete.components.TreeTableComponent {
            public TreeTableComponent(@NonNull ComponentIdentifier componentIdentifier) {
                super(componentIdentifier);
            }
    
    
        /**
         * 
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param exists 
         *        whether existence is expected or not
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkExistenceOfAColumn(@NonNull String column,@NonNull Operator columnOperator,@NonNull Boolean exists,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(exists, "Argument 'exists' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcCheckExistenceOfColumn")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(exists)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param exists 
         *        whether existence is expected or not
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkExistenceOfAColumn(@NonNull String column,@NonNull Operator columnOperator,@NonNull Boolean exists
        ) throws IllegalArgumentException {
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(exists, "Argument 'exists' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcCheckExistenceOfColumn")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(exists)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param textpath 
         *        the textpath to use
         * @param operator 
         *        the operator used for comparison
         * @param numberOfClicks 
         *        the amount of interactions
         * @param column 
         *        the column
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * 
         */
        @NonNull public CAP selectEntryByTextpathSpecifyColumn(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String textpath,@NonNull Operator operator,@NonNull Integer numberOfClicks,@NonNull Integer column,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(textpath, "Argument 'textpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelect")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(textpath)
                        .addParameter(operator.rcValue())
                        .addParameter(numberOfClicks)
                        .addParameter(column)
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param indexpath 
         *        the 1-based indexpath e.g. "1/2/1"
         * @param numberOfClicks 
         *        the amount of interactions
         * @param column 
         *        the column
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * 
         */
        @NonNull public CAP selectEntryByIndexpathSpecifyColumn(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String indexpath,@NonNull Integer numberOfClicks,@NonNull Integer column,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(indexpath, "Argument 'indexpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelectByIndices")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(indexpath)
                        .addParameter(numberOfClicks)
                        .addParameter(column)
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
        /**
         * 
         * @param text 
         *        the text to use
         * @param operator 
         *        the operator used for comparison
         * @param column 
         *        the column
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * 
         */
        @NonNull public CAP checkSelectionByValueSSpecifyColumn(@NonNull String text,@NonNull Operator operator,@NonNull Integer column,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedValue")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(operator.rcValue())
                        .addParameter(column)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param text 
         *        the text to use
         * @param operator 
         *        the operator used for comparison
         * @param column 
         *        the column
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * 
         */
        @NonNull public CAP checkSelectionByValueSSpecifyColumn(@NonNull String text,@NonNull Operator operator,@NonNull Integer column
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedValue")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(operator.rcValue())
                        .addParameter(column)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param textpath 
         *        the textpath to use
         * @param operator 
         *        the operator used for comparison
         * @param numberOfClicks 
         *        the amount of interactions
         * @param column 
         *        the column
         * @param columnOperator 
         *        the operator used for comparison
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP selectEntryByTextpathSpecifyColumnPath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String textpath,@NonNull Operator operator,@NonNull Integer numberOfClicks,@NonNull String column,@NonNull Operator columnOperator,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(textpath, "Argument 'textpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelectColumnPath")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(textpath)
                        .addParameter(operator.rcValue())
                        .addParameter(numberOfClicks)
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
        /**
         * 
         * @param pathType 
         *        whether the given path is a relative or absolute path
         * @param preAscend 
         *        the amount of implicit pre-ascends; similiar to the amount of ".." in path navigations
         * @param indexpath 
         *        the 1-based indexpath e.g. "1/2/1"
         * @param numberOfClicks 
         *        the amount of interactions
         * @param column 
         *        the column
         * @param operator 
         *        the operator used for comparison
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP selectEntryByIndexpathSpecifyColumnPath(@NonNull SearchType pathType,@NonNull Integer preAscend,@NonNull String indexpath,@NonNull Integer numberOfClicks,@NonNull String column,@NonNull Operator operator,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(pathType, "Argument 'pathType' must not be null"); //$NON-NLS-1$
            Validate.notNull(preAscend, "Argument 'preAscend' must not be null"); //$NON-NLS-1$
            Validate.notNull(indexpath, "Argument 'indexpath' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelectByColumnPath")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(pathType.rcValue())
                        .addParameter(preAscend)
                        .addParameter(indexpath)
                        .addParameter(numberOfClicks)
                        .addParameter(column)
                        .addParameter(operator.rcValue())
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
        /**
         * 
         * @param text 
         *        the text to use
         * @param operator 
         *        the operator used for comparison
         * @param column 
         *        the column
         * @param columnOperator 
         *        the operator used for comparison
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionByValueSSpecifyColumnPath(@NonNull String text,@NonNull Operator operator,@NonNull String column,@NonNull Operator columnOperator,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedValueAtPath")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(operator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param text 
         *        the text to use
         * @param operator 
         *        the operator used for comparison
         * @param column 
         *        the column
         * @param columnOperator 
         *        the operator used for comparison
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkSelectionByValueSSpecifyColumnPath(@NonNull String text,@NonNull Operator operator,@NonNull String column,@NonNull Operator columnOperator
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedValueAtPath")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(operator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(0)
                        .build();
        }
        
        /**
         * Use this action to check the text in a cell based on the current position of the cursor
         * @param text 
         *        the text to use
         * @param operator 
         *        the operator used for comparison
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkTextOfCellMousePosition(@NonNull String text,@NonNull Operator operator,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyCellTextAtMousePosition")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(operator.rcValue())
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * Use this action to check the text in a cell based on the current position of the cursor
         * @param text 
         *        the text to use
         * @param operator 
         *        the operator used for comparison
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkTextOfCellMousePosition(@NonNull String text,@NonNull Operator operator
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(operator, "Argument 'operator' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyCellTextAtMousePosition")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(operator.rcValue())
                        .addParameter(0)
                        .build();
        }
        
        
        /**
         * Use this action to read the value in the cell where the mouse is currently placed so that you can use the value in the cell as data for other Test Steps
         * @since 4.1
         */
        @NonNull public CAP getValueAtMousePosition(
        )  {
            
            return new CapBuilder("rcReadValueAtMousePosition")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .build();
        }
        
        /**
         * 
         * @param editable 
         *        whether the component is expected to be editable or not
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkEditabilitySpecifyCell(@NonNull Boolean editable,@NonNull String row,@NonNull Operator rowOperator,@NonNull String column,@NonNull Operator columnOperator,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(editable, "Argument 'editable' must not be null"); //$NON-NLS-1$
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyEditable")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(editable)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param editable 
         *        whether the component is expected to be editable or not
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkEditabilitySpecifyCell(@NonNull Boolean editable,@NonNull String row,@NonNull Operator rowOperator,@NonNull String column,@NonNull Operator columnOperator
        ) throws IllegalArgumentException {
            Validate.notNull(editable, "Argument 'editable' must not be null"); //$NON-NLS-1$
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyEditable")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(editable)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(0)
                        .build();
        }
        
        /**
         * Use this action to check whether a cell at the current mouse position is editable or not
         * @param editable 
         *        whether the component is expected to be editable or not
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkEditabilityOfCellMousePosition(@NonNull Boolean editable,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(editable, "Argument 'editable' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyEditableMousePosition")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(editable)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * Use this action to check whether a cell at the current mouse position is editable or not
         * @param editable 
         *        whether the component is expected to be editable or not
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkEditabilityOfCellMousePosition(@NonNull Boolean editable
        ) throws IllegalArgumentException {
            Validate.notNull(editable, "Argument 'editable' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyEditableMousePosition")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(editable)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * Use this action to check whether the currently selected cell is editable or not
         * @param editable 
         *        whether the component is expected to be editable or not
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkEditabilityOfSelectedCell(@NonNull Boolean editable,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(editable, "Argument 'editable' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedEditable")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(editable)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * Use this action to check whether the currently selected cell is editable or not
         * @param editable 
         *        whether the component is expected to be editable or not
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkEditabilityOfSelectedCell(@NonNull Boolean editable
        ) throws IllegalArgumentException {
            Validate.notNull(editable, "Argument 'editable' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifySelectedEditable")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(editable)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param value 
         *        the cell value
         * @param valueOperator 
         *        the operator used to compare the values
         * @param searchType 
         *        the search type
         * @param exists 
         *        whether existence is expected or not
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkExistenceOfValueInRow(@NonNull String row,@NonNull Operator rowOperator,@NonNull String value,@NonNull Operator valueOperator,@NonNull SearchType searchType,@NonNull Boolean exists,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(value, "Argument 'value' must not be null"); //$NON-NLS-1$
            Validate.notNull(valueOperator, "Argument 'valueOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(searchType, "Argument 'searchType' must not be null"); //$NON-NLS-1$
            Validate.notNull(exists, "Argument 'exists' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyValueInRow")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(value)
                        .addParameter(valueOperator.rcValue())
                        .addParameter(searchType.rcValue())
                        .addParameter(exists)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param value 
         *        the cell value
         * @param valueOperator 
         *        the operator used to compare the values
         * @param searchType 
         *        the search type
         * @param exists 
         *        whether existence is expected or not
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkExistenceOfValueInRow(@NonNull String row,@NonNull Operator rowOperator,@NonNull String value,@NonNull Operator valueOperator,@NonNull SearchType searchType,@NonNull Boolean exists
        ) throws IllegalArgumentException {
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(value, "Argument 'value' must not be null"); //$NON-NLS-1$
            Validate.notNull(valueOperator, "Argument 'valueOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(searchType, "Argument 'searchType' must not be null"); //$NON-NLS-1$
            Validate.notNull(exists, "Argument 'exists' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyValueInRow")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(value)
                        .addParameter(valueOperator.rcValue())
                        .addParameter(searchType.rcValue())
                        .addParameter(exists)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param value 
         *        the cell value
         * @param valueOperator 
         *        the operator used to compare the values
         * @param searchType 
         *        the search type
         * @param exists 
         *        whether existence is expected or not
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkExistenceOfValueInColumn(@NonNull String column,@NonNull Operator columnOperator,@NonNull String value,@NonNull Operator valueOperator,@NonNull SearchType searchType,@NonNull Boolean exists,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(value, "Argument 'value' must not be null"); //$NON-NLS-1$
            Validate.notNull(valueOperator, "Argument 'valueOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(searchType, "Argument 'searchType' must not be null"); //$NON-NLS-1$
            Validate.notNull(exists, "Argument 'exists' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyValueInColumn")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(value)
                        .addParameter(valueOperator.rcValue())
                        .addParameter(searchType.rcValue())
                        .addParameter(exists)
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param value 
         *        the cell value
         * @param valueOperator 
         *        the operator used to compare the values
         * @param searchType 
         *        the search type
         * @param exists 
         *        whether existence is expected or not
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkExistenceOfValueInColumn(@NonNull String column,@NonNull Operator columnOperator,@NonNull String value,@NonNull Operator valueOperator,@NonNull SearchType searchType,@NonNull Boolean exists
        ) throws IllegalArgumentException {
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(value, "Argument 'value' must not be null"); //$NON-NLS-1$
            Validate.notNull(valueOperator, "Argument 'valueOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(searchType, "Argument 'searchType' must not be null"); //$NON-NLS-1$
            Validate.notNull(exists, "Argument 'exists' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyValueInColumn")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(value)
                        .addParameter(valueOperator.rcValue())
                        .addParameter(searchType.rcValue())
                        .addParameter(exists)
                        .addParameter(0)
                        .build();
        }
        
        /**
         * 
         * @param text 
         *        the text to use
         * @param textOperator 
         *        the text operator
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param timeoutInMs 
         *        the dynamic timeout in ms
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkTextSpecifyCell(@NonNull String text,@NonNull Operator textOperator,@NonNull String row,@NonNull Operator rowOperator,@NonNull String column,@NonNull Operator columnOperator,@NonNull Integer timeoutInMs
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(textOperator, "Argument 'textOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(timeoutInMs, "Argument 'timeoutInMs' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyText")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(textOperator.rcValue())
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(timeoutInMs)
                        .build();
        }
        /**
         * 
         * @param text 
         *        the text to use
         * @param textOperator 
         *        the text operator
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP checkTextSpecifyCell(@NonNull String text,@NonNull Operator textOperator,@NonNull String row,@NonNull Operator rowOperator,@NonNull String column,@NonNull Operator columnOperator
        ) throws IllegalArgumentException {
            Validate.notNull(text, "Argument 'text' must not be null"); //$NON-NLS-1$
            Validate.notNull(textOperator, "Argument 'textOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcVerifyText")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(text)
                        .addParameter(textOperator.rcValue())
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(0)
                        .build();
        }
        
        
        /**
         * Use this action to read the value of the specified cell so that you can use the value in the cell as data for other Test Steps
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP getValueSpecifyCell(@NonNull String row,@NonNull Operator rowOperator,@NonNull String column,@NonNull Operator columnOperator
        ) throws IllegalArgumentException {
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcReadValue")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .build();
        }
        
        /**
         * 
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param numberOfClicks 
         *        the amount of interactions
         * @param xPosition 
         *        the x-position
         * @param xUnits 
         *        the unit of the x-position
         * @param yPosition 
         *        the y-position
         * @param yUnits 
         *        the unit of the y-position
         * @param extendSelection 
         *        whether to extend the selection or not
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP selectCell(@NonNull String row,@NonNull Operator rowOperator,@NonNull String column,@NonNull Operator columnOperator,@NonNull Integer numberOfClicks,@NonNull Integer xPosition,@NonNull Unit xUnits,@NonNull Integer yPosition,@NonNull Unit yUnits,@NonNull BinaryChoice extendSelection,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(xPosition, "Argument 'xPosition' must not be null"); //$NON-NLS-1$
            Validate.notNull(xUnits, "Argument 'xUnits' must not be null"); //$NON-NLS-1$
            Validate.notNull(yPosition, "Argument 'yPosition' must not be null"); //$NON-NLS-1$
            Validate.notNull(yUnits, "Argument 'yUnits' must not be null"); //$NON-NLS-1$
            Validate.notNull(extendSelection, "Argument 'extendSelection' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelectCell")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(numberOfClicks)
                        .addParameter(xPosition)
                        .addParameter(xUnits.rcValue())
                        .addParameter(yPosition)
                        .addParameter(yUnits.rcValue())
                        .addParameter(extendSelection.rcValue())
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
        /**
         * 
         * @param column 
         *        the column
         * @param columnOperator 
         *        the column operator
         * @param value 
         *        the cell value
         * @param valueOperator 
         *        the operator used to compare the values
         * @param numberOfClicks 
         *        the amount of interactions
         * @param extendSelection 
         *        whether to extend the selection or not
         * @param searchType 
         *        the search type
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP selectValueFromColumn(@NonNull String column,@NonNull Operator columnOperator,@NonNull String value,@NonNull Operator valueOperator,@NonNull Integer numberOfClicks,@NonNull BinaryChoice extendSelection,@NonNull SearchType searchType,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(column, "Argument 'column' must not be null"); //$NON-NLS-1$
            Validate.notNull(columnOperator, "Argument 'columnOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(value, "Argument 'value' must not be null"); //$NON-NLS-1$
            Validate.notNull(valueOperator, "Argument 'valueOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(extendSelection, "Argument 'extendSelection' must not be null"); //$NON-NLS-1$
            Validate.notNull(searchType, "Argument 'searchType' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelectRowByValue")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(column)
                        .addParameter(columnOperator.rcValue())
                        .addParameter(value)
                        .addParameter(valueOperator.rcValue())
                        .addParameter(numberOfClicks)
                        .addParameter(extendSelection.rcValue())
                        .addParameter(searchType.rcValue())
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
        /**
         * 
         * @param row 
         *        the row
         * @param rowOperator 
         *        the row operator
         * @param value 
         *        the cell value
         * @param valueOperator 
         *        the operator used to compare the values
         * @param numberOfClicks 
         *        the amount of interactions
         * @param extendSelection 
         *        whether to extend the selection or not
         * @param searchType 
         *        the search type
         * @param mouseButton 
         *        the interaction type e.g. on desktop systems the mouse button
         * @throws IllegalArgumentException if one of the passed parameters is <code>null</code>.
         * @since 4.1
         */
        @NonNull public CAP selectValueFromRow(@NonNull String row,@NonNull Operator rowOperator,@NonNull String value,@NonNull Operator valueOperator,@NonNull Integer numberOfClicks,@NonNull BinaryChoice extendSelection,@NonNull SearchType searchType,@NonNull InteractionMode mouseButton
        ) throws IllegalArgumentException {
            Validate.notNull(row, "Argument 'row' must not be null"); //$NON-NLS-1$
            Validate.notNull(rowOperator, "Argument 'rowOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(value, "Argument 'value' must not be null"); //$NON-NLS-1$
            Validate.notNull(valueOperator, "Argument 'valueOperator' must not be null"); //$NON-NLS-1$
            Validate.notNull(numberOfClicks, "Argument 'numberOfClicks' must not be null"); //$NON-NLS-1$
            Validate.notNull(extendSelection, "Argument 'extendSelection' must not be null"); //$NON-NLS-1$
            Validate.notNull(searchType, "Argument 'searchType' must not be null"); //$NON-NLS-1$
            Validate.notNull(mouseButton, "Argument 'mouseButton' must not be null"); //$NON-NLS-1$
            
            return new CapBuilder("rcSelectCellByColValue")
                        .setDefaultMapping(false)
                        .setComponentIdentifier(m_componentIdentifier)
                        .addParameter(row)
                        .addParameter(rowOperator.rcValue())
                        .addParameter(value)
                        .addParameter(valueOperator.rcValue())
                        .addParameter(numberOfClicks)
                        .addParameter(extendSelection.rcValue())
                        .addParameter(searchType.rcValue())
                        .addParameter(mouseButton.rcIntValue())
                        .build();
        }
        
} 